@@ -2,8 +2,8 @@ l1pcahp <- function (X, projDim=1, center=TRUE, projections="none", initialize="
 {
   
   
-  if (class(X) != "matrix") {
-    if (class(X) == "data.frame")
+  if (!inherits(X, "matrix")) {
+    if (inherits(X, "data.frame"))
       X <- as.matrix(X)
     else
       X <- matrix(X, ncol = 1)
